@@ -14,6 +14,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+# FIXME(yoctozepto): this module does *not* validate "common_options" which are
+# a hacky way to seed most usages of kolla_docker in kolla-ansible ansible
+# playbooks - caution has to be exerted when setting "common_options"
+
+# FIXME(yoctozepto): restart_policy is *not* checked in the container
+
 import json
 import os
 import shlex
@@ -45,6 +51,7 @@ options:
       - compare_container
       - compare_image
       - create_volume
+      - ensure_image
       - get_container_env
       - get_container_state
       - pull_image
@@ -55,6 +62,7 @@ options:
       - restart_container
       - start_container
       - stop_container
+      - stop_container_and_remove_container
   api_version:
     description:
       - The version of the api for docker-py to use when contacting docker
@@ -155,17 +163,17 @@ options:
     type: bool
   restart_policy:
     description:
-      - Determine what docker does when the container exits
+      - When docker restarts the container (does not affect checks)
     required: False
     type: str
     choices:
-      - never
+      - no
       - on-failure
       - always
       - unless-stopped
   restart_retries:
     description:
-      - How many times to attempt a restart if restart_policy is set
+      - How many times to attempt a restart if 'on-failure' policy is set
     type: int
     default: 10
   volumes:
@@ -681,16 +689,17 @@ class DockerWorker(object):
             dimensions = self.parse_dimensions(dimensions)
             options.update(dimensions)
 
-        if self.params.get('restart_policy') in ['on-failure',
-                                                 'always',
-                                                 'unless-stopped']:
-            policy = {'Name': self.params.get('restart_policy')}
+        restart_policy = self.params.get('restart_policy')
+
+        if restart_policy is not None:
+            restart_policy = {'Name': restart_policy}
             # NOTE(Jeffrey4l): MaximumRetryCount is only needed for on-failure
             # policy
-            if self.params.get('restart_policy') == 'on-failure':
+            if restart_policy['Name'] == 'on-failure':
                 retries = self.params.get('restart_retries')
-                policy['MaximumRetryCount'] = retries
-            options['restart_policy'] = policy
+                if retries is not None:
+                    restart_policy['MaximumRetryCount'] = retries
+            options['restart_policy'] = restart_policy
 
         if binds:
             options['binds'] = binds
@@ -830,6 +839,12 @@ class DockerWorker(object):
             self.changed = True
             self.dc.stop(name, timeout=graceful_timeout)
 
+    def stop_and_remove_container(self):
+        container = self.check_container()
+        if container:
+            self.stop_container()
+            self.remove_container()
+
     def restart_container(self):
         name = self.params.get('name')
         graceful_timeout = self.params.get('graceful_timeout')
@@ -884,6 +899,10 @@ class DockerWorker(object):
                     )
                 raise
 
+    def ensure_image(self):
+        if not self.check_image():
+            self.pull_image()
+
 
 def generate_module():
     # NOTE(jeffrey4l): add empty string '' to choices let us use
@@ -891,13 +910,21 @@ def generate_module():
     argument_spec = dict(
         common_options=dict(required=False, type='dict', default=dict()),
         action=dict(required=True, type='str',
-                    choices=['compare_container', 'compare_image',
-                             'create_volume', 'get_container_env',
-                             'get_container_state', 'pull_image',
+                    choices=['compare_container',
+                             'compare_image',
+                             'create_volume',
+                             'ensure_image',
+                             'get_container_env',
+                             'get_container_state',
+                             'pull_image',
                              'recreate_or_restart_container',
-                             'remove_container', 'remove_image',
-                             'remove_volume', 'restart_container',
-                             'start_container', 'stop_container']),
+                             'remove_container',
+                             'remove_image',
+                             'remove_volume',
+                             'restart_container',
+                             'start_container',
+                             'stop_container',
+                             'stop_and_remove_container']),
         api_version=dict(required=False, type='str', default='auto'),
         auth_email=dict(required=False, type='str'),
         auth_password=dict(required=False, type='str', no_log=True),
@@ -921,7 +948,6 @@ def generate_module():
         remove_on_exit=dict(required=False, type='bool', default=True),
         restart_policy=dict(required=False, type='str', choices=[
                             'no',
-                            'never',
                             'on-failure',
                             'always',
                             'unless-stopped']),
@@ -946,6 +972,7 @@ def generate_module():
         ['action', 'compare_container', ['name']],
         ['action', 'compare_image', ['name']],
         ['action', 'create_volume', ['name']],
+        ['action', 'ensure_image', ['image']],
         ['action', 'get_container_env', ['name']],
         ['action', 'get_container_state', ['name']],
         ['action', 'recreate_or_restart_container', ['name']],
@@ -953,7 +980,8 @@ def generate_module():
         ['action', 'remove_image', ['image']],
         ['action', 'remove_volume', ['name']],
         ['action', 'restart_container', ['name']],
-        ['action', 'stop_container', ['name']]
+        ['action', 'stop_container', ['name']],
+        ['action', 'stop_and_remove_container', ['name']],
     ]
     module = AnsibleModule(
         argument_spec=argument_spec,
